@@ -54,15 +54,19 @@ def sign_up_hub(email, handle) -> Union[str, None]:
 
 def sign_in_hub(email, password, handle=None):
     hub = connect_hub()
-    session = hub.auth.sign_in(email=email, password=password)
+    try:
+        session = hub.auth.sign_in(email=email, password=password)
+    except Exception:  # this is bad, but I don't find APIError right now
+        logger.error("Could not login. Probably your password is wrong.")
+        return "could-not-login"
     data = hub.table("usermeta").select("*").eq("id", session.user.id.hex).execute()
     if len(data.data) > 0:  # user is completely registered
         user_id = data.data[0]["lnid"]
         user_handle = data.data[0]["handle"]
-        if handle != user_handle:
+        if handle is not None and handle != user_handle:
             logger.warning(
                 f"Provided handle {handle} does not match your account handle"
-                f" {user_handle}. Using account handle!"
+                f" {user_handle}! Using account handle {user_handle}."
             )
     else:  # user registration on hub gets completed below
         user_id = id.id_user()
